@@ -2,6 +2,7 @@ from dataclasses import dataclass, asdict
 from inspect import signature as inspectSignature
 from json import dumps as dumpJson
 from json import loads as loadJson
+from typing import List, Dict
 
 from requests import Response, get, patch, post, put
 
@@ -23,10 +24,10 @@ class YNABTransaction:
     subtransactions: list = None
     cleared: str = 'cleared'
 
-    def __post_init__(self):
+    def __post_init__(self) -> None:
         self.payee_name = self.payee_name[:100]
 
-    def asdict(self):
+    def asdict(self) -> dict:
         return asdict(self)
 
     @classmethod
@@ -40,28 +41,28 @@ class YNABTransaction:
 class YNABAPI():
 
     def __init__(self, api_key: str) -> None:
-        self.uri = 'https://api.youneedabudget.com/v1/'
+        self.uri = 'https://api.youneedabudget.com/v1'
         self.headers = {
             "Content-Type": "application/json",
             "Authorization": f"Bearer {api_key}"
         }
         self.budget_id: str = None
 
-    def _patch(self, url: str, **kwargs):
+    def _patch(self, url: str, **kwargs) -> Response:
         return patch(self.uri + url, **kwargs, headers=self.headers)
 
-    def _post(self, url: str, **kwargs):
+    def _post(self, url: str, **kwargs) -> Response:
         return post(self.uri + url, **kwargs, headers=self.headers)
 
-    def _put(self, url: str, **kwargs):
+    def _put(self, url: str, **kwargs) -> Response:
         return put(self.uri + url, **kwargs, headers=self.headers)
 
-    def _get(self, url: str, **kwargs):
+    def _get(self, url: str, **kwargs) -> Response:
         return get(self.uri + url, **kwargs, headers=self.headers)
 
 # User
 
-    def get_user(self):
+    def get_user(self) -> dict:
         """Returns authenticated user information
         """
         return _decode(self._get(f'/user')['user'])
@@ -171,7 +172,7 @@ class YNABAPI():
 
 # Categories
 
-    def get_categories(self, budget_id: str = None):
+    def get_categories(self, budget_id: str = None) -> dict:
         """List categories
 
         Amounts (budgeted, activity, balance, etc.) are specific to the current budget month (UTC).
@@ -395,7 +396,6 @@ class YNABAPI():
         url = f'/budgets/{budget_id}/months/{month}'
         return _decode(self._get(url=url))['month']
 
-
 # Transactions
 
     def get_transactions(
@@ -403,9 +403,9 @@ class YNABAPI():
         since_date: str = None,
         type: str = None,
         budget_id: str = None,
-    ) -> dict[list[YNABTransaction]]:
+    ) -> Dict[str, List[YNABTransaction]]:
         """List transactions as YNABTransactions.
-        
+
         Args:
             since_date (str, optional): If specified, only transactions on or after this date will be included.
             The date should be ISO formatted (e.g. 2016-12-30).
@@ -415,7 +415,7 @@ class YNABAPI():
             last used budget and “default” can be used if default budget selection is enabled.
             If not specified, defaults to self.budget_id
         Returns:
-            dict[list[YNABTransaction]]: budget transactions
+            Dict[str, List[YNABTransaction]]: budget transactions
         """
         budget_id = _oneOf(budget_id, self.budget_id)
         url = f'/budgets/{budget_id}/transactions'
@@ -431,9 +431,9 @@ class YNABAPI():
         self,
         transaction_id: str,
         budget_id: str = None,
-    ) -> dict[YNABTransaction]:
+    ) -> Dict[str, YNABTransaction]:
         """Single transaction
-        
+
         Args:
             transaction_id (str): The id of the transaction
             budget_id (str, optional): The id of the budget. “last-used” can be used to specify the
@@ -441,7 +441,7 @@ class YNABAPI():
             If not specified, defaults to self.budget_id
 
         Returns:
-            dict[YNABTransaction]: requested transaction
+            Dict[str, YNABTransaction]: requested transaction
         """
         budget_id = _oneOf(budget_id, self.budget_id)
         url = f'/budgets/{budget_id}/transactions/{transaction_id}'
@@ -454,7 +454,7 @@ class YNABAPI():
         budget_id: str = None,
         since_date: str = None,
         type: str = None,
-    ) -> dict[YNABTransaction]:
+    ) -> Dict[str, YNABTransaction]:
         budget_id = _oneOf(budget_id, self.budget_id)
         url = f'/budgets/{budget_id}/accounts/{account_id}/transactions'
         data = {
@@ -474,7 +474,7 @@ class YNABAPI():
         budget_id: str = None,
         since_date: str = None,
         type: str = None,
-    ) -> dict[YNABTransaction]:
+    ) -> Dict[str, YNABTransaction]:
         budget_id = _oneOf(budget_id, self.budget_id)
         url = f'/budgets/{budget_id}/transactions/{category_id}'
         data = {
@@ -494,7 +494,7 @@ class YNABAPI():
         budget_id: str = None,
         since_date: str = None,
         type: str = None,
-    ) -> dict[YNABTransaction]:
+    ) -> Dict[str, YNABTransaction]:
         budget_id = _oneOf(budget_id, self.budget_id)
         url = f'/budgets/{budget_id}/transactions/{payee_id}'
         data = {
@@ -513,9 +513,9 @@ class YNABAPI():
         transaction_id: str,
         updated_transaction: YNABTransaction,
         budget_id: str = None,
-    ) -> dict[YNABTransaction]:
+    ) -> Dict[str, YNABTransaction]:
         """Updates a single transaction
-        
+
         Args:
             transaction_id (str): The id of the transaction
             budget_id (str, optional): The id of the budget. “last-used” can be used to specify the
@@ -524,7 +524,7 @@ class YNABAPI():
             updated_transaction (YNABTransaction): transaction with new values
 
         Returns:
-            dict[YNABTransaction]: updated transaction
+            Dict[str, YNABTransaction]: updated transaction
         """
         budget_id = _oneOf(budget_id, self.budget_id)
         url = f'/budgets/{budget_id}/transactions/{transaction_id}'
@@ -534,14 +534,14 @@ class YNABAPI():
 
     def post_transactions(
         self,
-        transactions: YNABTransaction | list[YNABTransaction],
+        transactions: YNABTransaction or List[YNABTransaction],
         budget_id: str = None,
     ) -> dict:
         """Create a single transaction or multiple transactions.
         Scheduled transactions cannot be created on this endpoint.
 
         Args:
-            transactions (YNABTransaction | list[YNABTransaction]): either single transaction or list of transactions
+            transactions (YNABTransaction or List[YNABTransaction]): either single transaction or list of transactions
 
         Returns:
             dict: successfully created transactions
@@ -554,13 +554,13 @@ class YNABAPI():
 
     def post_import_transactions(
         self,
-        transactions: YNABTransaction | list[YNABTransaction],
+        transactions: YNABTransaction or List[YNABTransaction],
         budget_id: str = None,
-    ):
+    ) -> dict:
         """Same as post_transactions, but sent to the Import endpoint.
 
         Args:
-            transactions (YNABTransaction | list[YNABTransaction]): _description_
+            transactions (YNABTransaction or List[YNABTransaction]): _description_
         """
         budget_id = _oneOf(budget_id, self.budget_id)
         url = f'/budgets/{budget_id}/transactions/import'
@@ -570,13 +570,13 @@ class YNABAPI():
 
     def patch_transactions(
         self,
-        transactions: YNABTransaction | list[YNABTransaction],
+        transactions: YNABTransaction or List[YNABTransaction],
         budget_id: str = None,
-    ):
+    ) -> dict:
         """Updates multiple transactions, by id or import_id.
 
         Args:
-            transactions (YNABTransaction | list[YNABTransaction]): either single transaction or list of transactions
+            transactions (YNABTransaction or List[YNABTransaction]): either single transaction or list of transactions
 
         Returns:
             dict: successfully updated transactions
@@ -609,7 +609,7 @@ class YNABAPI():
     def get_scheduled_transactions(
         self,
         budget_id: str = None,
-    ) -> dict[list]:
+    ) -> Dict[str, list]:
         """List scheduled transactions
 
         Args:
@@ -629,7 +629,7 @@ class YNABAPI():
         self,
         scheduled_transaction_id: str,
         budget_id: str = None,
-    ) -> dict[list]:
+    ) -> Dict[str, list]:
         """Single scheduled transaction
 
         Args:
@@ -639,7 +639,7 @@ class YNABAPI():
             If not specified, defaults to self.budget_id
 
         Returns:
-            dict[YNABTransaction]: a single scheduled transaction
+            Dict[str, YNABTransaction]: a single scheduled transaction
         """
         budget_id = _oneOf(budget_id, self.budget_id)
         url = f'/budgets/{budget_id}/scheduled_transactions/{scheduled_transaction_id}'
@@ -648,15 +648,14 @@ class YNABAPI():
 
 
 def _decode(httpResponse: Response) -> dict:
-    answer = loadJson(httpResponse.content.decode('utf-8'))
-    try:
+    answer: dict = loadJson(httpResponse.content.decode('utf-8'))
+    if 'data' in answer.keys():
         return answer['data']
-    except KeyError:
-        print(answer['error'])
+    raise Exception(answer['error'])
 
 
 def _oneOf(this, that):
-    return that if this == None else this
+    return that if this is None else this
 
 
 _account_types = [
