@@ -1,6 +1,7 @@
 import json
 import os
 from dataclasses import dataclass
+from json import JSONDecodeError
 
 from .ynam_parser import arg
 
@@ -19,9 +20,14 @@ class Secrets():
 
 def loadSecrets():
     fileSecrets = {}
-    if os.path.exists(arg('config_file_path')):
-        with open(arg('config_file_path'), 'r') as file:
-            fileSecrets = json.load(file)
+    path = arg('config_file')
+    if os.path.exists(path):
+        with open(path) as file:
+            try:
+                fileSecrets = json.load(file)
+            except JSONDecodeError:
+                print(f'Error reading {file.name}; assuming it to be empty')
+                return {}
 
     for key in {
             k: v
@@ -36,7 +42,7 @@ def updateStash(key, value):
     if value != '':
         secrets = {**loadSecrets()}
         secrets[key] = value
-        with open(arg('config_file_path'), 'w+') as file:
+        with open(arg('config_file'), 'w+') as file:
             file.write(json.dumps(secrets, indent=2))
 
 
